Documentation
¶
Overview ¶
Package maintpb is a generated protocol buffer package.
It is generated from these files:
maintner.proto
It has these top-level messages:
Mutation GithubMutation GithubIssueMutation BoolChange GithubLabel GithubMilestone GithubIssueEvent GithubCommit GithubIssueSyncStatus GithubIssueCommentMutation GithubUser GitMutation GitRepo GitCommit GitDiffTree GitDiffTreeFile GerritMutation GitRef
Index ¶
- type BoolChange
- type GerritMutation
- func (*GerritMutation) Descriptor() ([]byte, []int)
- func (m *GerritMutation) GetCommits() []*GitCommit
- func (m *GerritMutation) GetProject() string
- func (m *GerritMutation) GetRefs() []*GitRef
- func (*GerritMutation) ProtoMessage()
- func (m *GerritMutation) Reset()
- func (m *GerritMutation) String() string
- type GitCommit
- type GitDiffTree
- type GitDiffTreeFile
- func (*GitDiffTreeFile) Descriptor() ([]byte, []int)
- func (m *GitDiffTreeFile) GetAdded() int64
- func (m *GitDiffTreeFile) GetBinary() bool
- func (m *GitDiffTreeFile) GetDeleted() int64
- func (m *GitDiffTreeFile) GetFile() string
- func (*GitDiffTreeFile) ProtoMessage()
- func (m *GitDiffTreeFile) Reset()
- func (m *GitDiffTreeFile) String() string
- type GitMutation
- type GitRef
- type GitRepo
- type GithubCommit
- type GithubIssueCommentMutation
- func (*GithubIssueCommentMutation) Descriptor() ([]byte, []int)
- func (m *GithubIssueCommentMutation) GetBody() string
- func (m *GithubIssueCommentMutation) GetCreated() *google_protobuf.Timestamp
- func (m *GithubIssueCommentMutation) GetId() int64
- func (m *GithubIssueCommentMutation) GetUpdated() *google_protobuf.Timestamp
- func (m *GithubIssueCommentMutation) GetUser() *GithubUser
- func (*GithubIssueCommentMutation) ProtoMessage()
- func (m *GithubIssueCommentMutation) Reset()
- func (m *GithubIssueCommentMutation) String() string
- type GithubIssueEvent
- func (*GithubIssueEvent) Descriptor() ([]byte, []int)
- func (m *GithubIssueEvent) GetActorId() int64
- func (m *GithubIssueEvent) GetAssigneeId() int64
- func (m *GithubIssueEvent) GetAssignerId() int64
- func (m *GithubIssueEvent) GetCommit() *GithubCommit
- func (m *GithubIssueEvent) GetCreated() *google_protobuf.Timestamp
- func (m *GithubIssueEvent) GetEventType() string
- func (m *GithubIssueEvent) GetId() int64
- func (m *GithubIssueEvent) GetLabel() *GithubLabel
- func (m *GithubIssueEvent) GetMilestone() *GithubMilestone
- func (m *GithubIssueEvent) GetOtherJson() []byte
- func (m *GithubIssueEvent) GetRenameFrom() string
- func (m *GithubIssueEvent) GetRenameTo() string
- func (*GithubIssueEvent) ProtoMessage()
- func (m *GithubIssueEvent) Reset()
- func (m *GithubIssueEvent) String() string
- type GithubIssueMutation
- func (*GithubIssueMutation) Descriptor() ([]byte, []int)
- func (m *GithubIssueMutation) GetAddLabel() []*GithubLabel
- func (m *GithubIssueMutation) GetAssignees() []*GithubUser
- func (m *GithubIssueMutation) GetBody() string
- func (m *GithubIssueMutation) GetClosed() *BoolChange
- func (m *GithubIssueMutation) GetClosedAt() *google_protobuf.Timestamp
- func (m *GithubIssueMutation) GetClosedBy() *GithubUser
- func (m *GithubIssueMutation) GetComment() []*GithubIssueCommentMutation
- func (m *GithubIssueMutation) GetCommentStatus() *GithubIssueSyncStatus
- func (m *GithubIssueMutation) GetCreated() *google_protobuf.Timestamp
- func (m *GithubIssueMutation) GetDeletedAssignees() []int64
- func (m *GithubIssueMutation) GetEvent() []*GithubIssueEvent
- func (m *GithubIssueMutation) GetEventStatus() *GithubIssueSyncStatus
- func (m *GithubIssueMutation) GetId() int64
- func (m *GithubIssueMutation) GetLocked() *BoolChange
- func (m *GithubIssueMutation) GetMilestoneId() int64
- func (m *GithubIssueMutation) GetMilestoneNum() int64
- func (m *GithubIssueMutation) GetMilestoneTitle() string
- func (m *GithubIssueMutation) GetNoMilestone() bool
- func (m *GithubIssueMutation) GetNotExist() bool
- func (m *GithubIssueMutation) GetNumber() int32
- func (m *GithubIssueMutation) GetOwner() string
- func (m *GithubIssueMutation) GetRemoveLabel() []int64
- func (m *GithubIssueMutation) GetRepo() string
- func (m *GithubIssueMutation) GetTitle() string
- func (m *GithubIssueMutation) GetUpdated() *google_protobuf.Timestamp
- func (m *GithubIssueMutation) GetUser() *GithubUser
- func (*GithubIssueMutation) ProtoMessage()
- func (m *GithubIssueMutation) Reset()
- func (m *GithubIssueMutation) String() string
- type GithubIssueSyncStatus
- type GithubLabel
- type GithubMilestone
- func (*GithubMilestone) Descriptor() ([]byte, []int)
- func (m *GithubMilestone) GetClosed() *BoolChange
- func (m *GithubMilestone) GetId() int64
- func (m *GithubMilestone) GetNumber() int64
- func (m *GithubMilestone) GetTitle() string
- func (*GithubMilestone) ProtoMessage()
- func (m *GithubMilestone) Reset()
- func (m *GithubMilestone) String() string
- type GithubMutation
- func (*GithubMutation) Descriptor() ([]byte, []int)
- func (m *GithubMutation) GetLabels() []*GithubLabel
- func (m *GithubMutation) GetMilestones() []*GithubMilestone
- func (m *GithubMutation) GetOwner() string
- func (m *GithubMutation) GetRepo() string
- func (*GithubMutation) ProtoMessage()
- func (m *GithubMutation) Reset()
- func (m *GithubMutation) String() string
- type GithubUser
- type Mutation
- func (*Mutation) Descriptor() ([]byte, []int)
- func (m *Mutation) GetGerrit() *GerritMutation
- func (m *Mutation) GetGit() *GitMutation
- func (m *Mutation) GetGithub() *GithubMutation
- func (m *Mutation) GetGithubIssue() *GithubIssueMutation
- func (*Mutation) ProtoMessage()
- func (m *Mutation) Reset()
- func (m *Mutation) String() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BoolChange ¶
type BoolChange struct {
Val bool `protobuf:"varint,1,opt,name=val" json:"val,omitempty"`
}
BoolChange represents a change to a boolean value.
func (*BoolChange) Descriptor ¶
func (*BoolChange) Descriptor() ([]byte, []int)
func (*BoolChange) GetVal ¶
func (m *BoolChange) GetVal() bool
func (*BoolChange) ProtoMessage ¶
func (*BoolChange) ProtoMessage()
func (*BoolChange) Reset ¶
func (m *BoolChange) Reset()
func (*BoolChange) String ¶
func (m *BoolChange) String() string
type GerritMutation ¶
type GerritMutation struct {
// Project is the Gerrit server and project, without scheme (https implied) or
// trailing slash.
Project string `protobuf:"bytes,1,opt,name=project" json:"project,omitempty"`
// Commits to add.
Commits []*GitCommit `protobuf:"bytes,2,rep,name=commits" json:"commits,omitempty"`
// git refs to update.
Refs []*GitRef `protobuf:"bytes,3,rep,name=refs" json:"refs,omitempty"`
}
func (*GerritMutation) Descriptor ¶
func (*GerritMutation) Descriptor() ([]byte, []int)
func (*GerritMutation) GetCommits ¶
func (m *GerritMutation) GetCommits() []*GitCommit
func (*GerritMutation) GetProject ¶
func (m *GerritMutation) GetProject() string
func (*GerritMutation) GetRefs ¶
func (m *GerritMutation) GetRefs() []*GitRef
func (*GerritMutation) ProtoMessage ¶
func (*GerritMutation) ProtoMessage()
func (*GerritMutation) Reset ¶
func (m *GerritMutation) Reset()
func (*GerritMutation) String ¶
func (m *GerritMutation) String() string
type GitCommit ¶
type GitCommit struct {
Sha1 string `protobuf:"bytes,1,opt,name=sha1" json:"sha1,omitempty"`
// raw is the "git cat-file commit $sha1" output.
Raw []byte `protobuf:"bytes,2,opt,name=raw,proto3" json:"raw,omitempty"`
DiffTree *GitDiffTree `protobuf:"bytes,3,opt,name=diff_tree,json=diffTree" json:"diff_tree,omitempty"`
}
func (*GitCommit) Descriptor ¶
func (*GitCommit) GetDiffTree ¶
func (m *GitCommit) GetDiffTree() *GitDiffTree
func (*GitCommit) ProtoMessage ¶
func (*GitCommit) ProtoMessage()
type GitDiffTree ¶
type GitDiffTree struct {
File []*GitDiffTreeFile `protobuf:"bytes,1,rep,name=file" json:"file,omitempty"`
}
git diff-tree --numstat oldtree newtree
func (*GitDiffTree) Descriptor ¶
func (*GitDiffTree) Descriptor() ([]byte, []int)
func (*GitDiffTree) GetFile ¶
func (m *GitDiffTree) GetFile() []*GitDiffTreeFile
func (*GitDiffTree) ProtoMessage ¶
func (*GitDiffTree) ProtoMessage()
func (*GitDiffTree) Reset ¶
func (m *GitDiffTree) Reset()
func (*GitDiffTree) String ¶
func (m *GitDiffTree) String() string
type GitDiffTreeFile ¶
type GitDiffTreeFile struct {
File string `protobuf:"bytes,1,opt,name=file" json:"file,omitempty"`
Added int64 `protobuf:"varint,2,opt,name=added" json:"added,omitempty"`
Deleted int64 `protobuf:"varint,3,opt,name=deleted" json:"deleted,omitempty"`
Binary bool `protobuf:"varint,4,opt,name=binary" json:"binary,omitempty"`
}
GitDiffTreeFile represents one line of `git diff-tree --numstat` output.
func (*GitDiffTreeFile) Descriptor ¶
func (*GitDiffTreeFile) Descriptor() ([]byte, []int)
func (*GitDiffTreeFile) GetAdded ¶
func (m *GitDiffTreeFile) GetAdded() int64
func (*GitDiffTreeFile) GetBinary ¶
func (m *GitDiffTreeFile) GetBinary() bool
func (*GitDiffTreeFile) GetDeleted ¶
func (m *GitDiffTreeFile) GetDeleted() int64
func (*GitDiffTreeFile) GetFile ¶
func (m *GitDiffTreeFile) GetFile() string
func (*GitDiffTreeFile) ProtoMessage ¶
func (*GitDiffTreeFile) ProtoMessage()
func (*GitDiffTreeFile) Reset ¶
func (m *GitDiffTreeFile) Reset()
func (*GitDiffTreeFile) String ¶
func (m *GitDiffTreeFile) String() string
type GitMutation ¶
type GitMutation struct {
Repo *GitRepo `protobuf:"bytes,1,opt,name=repo" json:"repo,omitempty"`
// commit adds a commit, or adds new information to a commit if fields
// are added in the future.
Commit *GitCommit `protobuf:"bytes,2,opt,name=commit" json:"commit,omitempty"`
}
func (*GitMutation) Descriptor ¶
func (*GitMutation) Descriptor() ([]byte, []int)
func (*GitMutation) GetCommit ¶
func (m *GitMutation) GetCommit() *GitCommit
func (*GitMutation) GetRepo ¶
func (m *GitMutation) GetRepo() *GitRepo
func (*GitMutation) ProtoMessage ¶
func (*GitMutation) ProtoMessage()
func (*GitMutation) Reset ¶
func (m *GitMutation) Reset()
func (*GitMutation) String ¶
func (m *GitMutation) String() string
type GitRef ¶
type GitRef struct {
// ref is the git ref name, such as:
// HEAD
// refs/heads/master
// refs/changes/00/14700/1
// refs/changes/00/14700/meta
// refs/meta/config
Ref string `protobuf:"bytes,1,opt,name=ref" json:"ref,omitempty"`
// sha1 is the lowercase hex sha1
Sha1 string `protobuf:"bytes,2,opt,name=sha1" json:"sha1,omitempty"`
}
func (*GitRef) Descriptor ¶
func (*GitRef) ProtoMessage ¶
func (*GitRef) ProtoMessage()
type GitRepo ¶
type GitRepo struct {
// If go_repo is set, it identifies a go.googlesource.com/<go_repo> repo.
GoRepo string `protobuf:"bytes,1,opt,name=go_repo,json=goRepo" json:"go_repo,omitempty"`
}
GitRepo identifies a git repo being mutated.
func (*GitRepo) Descriptor ¶
func (*GitRepo) ProtoMessage ¶
func (*GitRepo) ProtoMessage()
type GithubCommit ¶
type GithubCommit struct {
Owner string `protobuf:"bytes,1,opt,name=owner" json:"owner,omitempty"`
Repo string `protobuf:"bytes,2,opt,name=repo" json:"repo,omitempty"`
CommitId string `protobuf:"bytes,3,opt,name=commit_id,json=commitId" json:"commit_id,omitempty"`
}
func (*GithubCommit) Descriptor ¶
func (*GithubCommit) Descriptor() ([]byte, []int)
func (*GithubCommit) GetCommitId ¶
func (m *GithubCommit) GetCommitId() string
func (*GithubCommit) GetOwner ¶
func (m *GithubCommit) GetOwner() string
func (*GithubCommit) GetRepo ¶
func (m *GithubCommit) GetRepo() string
func (*GithubCommit) ProtoMessage ¶
func (*GithubCommit) ProtoMessage()
func (*GithubCommit) Reset ¶
func (m *GithubCommit) Reset()
func (*GithubCommit) String ¶
func (m *GithubCommit) String() string
type GithubIssueCommentMutation ¶
type GithubIssueCommentMutation struct {
Id int64 `protobuf:"varint,1,opt,name=id" json:"id,omitempty"`
User *GithubUser `protobuf:"bytes,2,opt,name=user" json:"user,omitempty"`
Body string `protobuf:"bytes,3,opt,name=body" json:"body,omitempty"`
Created *google_protobuf.Timestamp `protobuf:"bytes,4,opt,name=created" json:"created,omitempty"`
Updated *google_protobuf.Timestamp `protobuf:"bytes,5,opt,name=updated" json:"updated,omitempty"`
}
func (*GithubIssueCommentMutation) Descriptor ¶
func (*GithubIssueCommentMutation) Descriptor() ([]byte, []int)
func (*GithubIssueCommentMutation) GetBody ¶
func (m *GithubIssueCommentMutation) GetBody() string
func (*GithubIssueCommentMutation) GetCreated ¶
func (m *GithubIssueCommentMutation) GetCreated() *google_protobuf.Timestamp
func (*GithubIssueCommentMutation) GetId ¶
func (m *GithubIssueCommentMutation) GetId() int64
func (*GithubIssueCommentMutation) GetUpdated ¶
func (m *GithubIssueCommentMutation) GetUpdated() *google_protobuf.Timestamp
func (*GithubIssueCommentMutation) GetUser ¶
func (m *GithubIssueCommentMutation) GetUser() *GithubUser
func (*GithubIssueCommentMutation) ProtoMessage ¶
func (*GithubIssueCommentMutation) ProtoMessage()
func (*GithubIssueCommentMutation) Reset ¶
func (m *GithubIssueCommentMutation) Reset()
func (*GithubIssueCommentMutation) String ¶
func (m *GithubIssueCommentMutation) String() string
type GithubIssueEvent ¶
type GithubIssueEvent struct {
// Required:
Id int64 `protobuf:"varint,1,opt,name=id" json:"id,omitempty"`
// event_type can be one of "assigned", "unassigned", "labeled",
// "unlabeled", "opened", "edited", "milestoned", "demilestoned",
// "closed", "reopened", "referenced", "renamed" or anything else
// that Github adds in the future.
EventType string `protobuf:"bytes,2,opt,name=event_type,json=eventType" json:"event_type,omitempty"`
ActorId int64 `protobuf:"varint,3,opt,name=actor_id,json=actorId" json:"actor_id,omitempty"`
Created *google_protobuf.Timestamp `protobuf:"bytes,4,opt,name=created" json:"created,omitempty"`
// label is populated for "labeled" and "unlabeled" events.
// The label will usually not have an ID, due to Github's API
// not returning one.
Label *GithubLabel `protobuf:"bytes,5,opt,name=label" json:"label,omitempty"`
// milestone is populated for "milestoned" and "demilestoned" events.
// The label will usually not have an ID, due to Github's API
// not returning one.
Milestone *GithubMilestone `protobuf:"bytes,6,opt,name=milestone" json:"milestone,omitempty"`
// For "assigned", "unassigned":
AssigneeId int64 `protobuf:"varint,7,opt,name=assignee_id,json=assigneeId" json:"assignee_id,omitempty"`
AssignerId int64 `protobuf:"varint,8,opt,name=assigner_id,json=assignerId" json:"assigner_id,omitempty"`
// For "referenced", "closed":
Commit *GithubCommit `protobuf:"bytes,9,opt,name=commit" json:"commit,omitempty"`
// For "renamed" events:
RenameFrom string `protobuf:"bytes,11,opt,name=rename_from,json=renameFrom" json:"rename_from,omitempty"`
RenameTo string `protobuf:"bytes,12,opt,name=rename_to,json=renameTo" json:"rename_to,omitempty"`
// other_json is usually empty. If Github adds event types or fields
// in the future, this captures those added fields. If non-empty it
// will be a JSON object with the fields that weren't understood.
OtherJson []byte `protobuf:"bytes,10,opt,name=other_json,json=otherJson,proto3" json:"other_json,omitempty"`
}
See https://developer.github.com/v3/activity/events/types/#issuesevent for some info.
func (*GithubIssueEvent) Descriptor ¶
func (*GithubIssueEvent) Descriptor() ([]byte, []int)
func (*GithubIssueEvent) GetActorId ¶
func (m *GithubIssueEvent) GetActorId() int64
func (*GithubIssueEvent) GetAssigneeId ¶
func (m *GithubIssueEvent) GetAssigneeId() int64
func (*GithubIssueEvent) GetAssignerId ¶
func (m *GithubIssueEvent) GetAssignerId() int64
func (*GithubIssueEvent) GetCommit ¶
func (m *GithubIssueEvent) GetCommit() *GithubCommit
func (*GithubIssueEvent) GetCreated ¶
func (m *GithubIssueEvent) GetCreated() *google_protobuf.Timestamp
func (*GithubIssueEvent) GetEventType ¶
func (m *GithubIssueEvent) GetEventType() string
func (*GithubIssueEvent) GetId ¶
func (m *GithubIssueEvent) GetId() int64
func (*GithubIssueEvent) GetLabel ¶
func (m *GithubIssueEvent) GetLabel() *GithubLabel
func (*GithubIssueEvent) GetMilestone ¶
func (m *GithubIssueEvent) GetMilestone() *GithubMilestone
func (*GithubIssueEvent) GetOtherJson ¶
func (m *GithubIssueEvent) GetOtherJson() []byte
func (*GithubIssueEvent) GetRenameFrom ¶
func (m *GithubIssueEvent) GetRenameFrom() string
func (*GithubIssueEvent) GetRenameTo ¶
func (m *GithubIssueEvent) GetRenameTo() string
func (*GithubIssueEvent) ProtoMessage ¶
func (*GithubIssueEvent) ProtoMessage()
func (*GithubIssueEvent) Reset ¶
func (m *GithubIssueEvent) Reset()
func (*GithubIssueEvent) String ¶
func (m *GithubIssueEvent) String() string
type GithubIssueMutation ¶
type GithubIssueMutation struct {
Owner string `protobuf:"bytes,1,opt,name=owner" json:"owner,omitempty"`
Repo string `protobuf:"bytes,2,opt,name=repo" json:"repo,omitempty"`
Number int32 `protobuf:"varint,3,opt,name=number" json:"number,omitempty"`
// not_exist is set true if the issue has been found to not exist.
// If true, the owner/repo/number fields above must still be set.
// If a future issue mutation for the same number arrives without
// not_exist set, then the issue comes back to life.
NotExist bool `protobuf:"varint,13,opt,name=not_exist,json=notExist" json:"not_exist,omitempty"`
Id int64 `protobuf:"varint,12,opt,name=id" json:"id,omitempty"`
User *GithubUser `protobuf:"bytes,4,opt,name=user" json:"user,omitempty"`
Assignees []*GithubUser `protobuf:"bytes,10,rep,name=assignees" json:"assignees,omitempty"`
DeletedAssignees []int64 `protobuf:"varint,11,rep,packed,name=deleted_assignees,json=deletedAssignees" json:"deleted_assignees,omitempty"`
Created *google_protobuf.Timestamp `protobuf:"bytes,5,opt,name=created" json:"created,omitempty"`
Updated *google_protobuf.Timestamp `protobuf:"bytes,6,opt,name=updated" json:"updated,omitempty"`
Body string `protobuf:"bytes,7,opt,name=body" json:"body,omitempty"`
Title string `protobuf:"bytes,9,opt,name=title" json:"title,omitempty"`
NoMilestone bool `protobuf:"varint,15,opt,name=no_milestone,json=noMilestone" json:"no_milestone,omitempty"`
// When setting a milestone, only the milestone_id must be set.
// TODO: allow num or title to be used if Github only returns those? So far unneeded.
// The num and title, if non-zero, are treated as if they were a GithubMutation.Milestone update.
MilestoneId int64 `protobuf:"varint,16,opt,name=milestone_id,json=milestoneId" json:"milestone_id,omitempty"`
MilestoneNum int64 `protobuf:"varint,17,opt,name=milestone_num,json=milestoneNum" json:"milestone_num,omitempty"`
MilestoneTitle string `protobuf:"bytes,18,opt,name=milestone_title,json=milestoneTitle" json:"milestone_title,omitempty"`
Closed *BoolChange `protobuf:"bytes,19,opt,name=closed" json:"closed,omitempty"`
Locked *BoolChange `protobuf:"bytes,25,opt,name=locked" json:"locked,omitempty"`
ClosedAt *google_protobuf.Timestamp `protobuf:"bytes,21,opt,name=closed_at,json=closedAt" json:"closed_at,omitempty"`
ClosedBy *GithubUser `protobuf:"bytes,22,opt,name=closed_by,json=closedBy" json:"closed_by,omitempty"`
RemoveLabel []int64 `protobuf:"varint,23,rep,packed,name=remove_label,json=removeLabel" json:"remove_label,omitempty"`
AddLabel []*GithubLabel `protobuf:"bytes,24,rep,name=add_label,json=addLabel" json:"add_label,omitempty"`
Comment []*GithubIssueCommentMutation `protobuf:"bytes,8,rep,name=comment" json:"comment,omitempty"`
CommentStatus *GithubIssueSyncStatus `protobuf:"bytes,14,opt,name=comment_status,json=commentStatus" json:"comment_status,omitempty"`
Event []*GithubIssueEvent `protobuf:"bytes,26,rep,name=event" json:"event,omitempty"`
EventStatus *GithubIssueSyncStatus `protobuf:"bytes,27,opt,name=event_status,json=eventStatus" json:"event_status,omitempty"`
}
func (*GithubIssueMutation) Descriptor ¶
func (*GithubIssueMutation) Descriptor() ([]byte, []int)
func (*GithubIssueMutation) GetAddLabel ¶
func (m *GithubIssueMutation) GetAddLabel() []*GithubLabel
func (*GithubIssueMutation) GetAssignees ¶
func (m *GithubIssueMutation) GetAssignees() []*GithubUser
func (*GithubIssueMutation) GetBody ¶
func (m *GithubIssueMutation) GetBody() string
func (*GithubIssueMutation) GetClosed ¶
func (m *GithubIssueMutation) GetClosed() *BoolChange
func (*GithubIssueMutation) GetClosedAt ¶
func (m *GithubIssueMutation) GetClosedAt() *google_protobuf.Timestamp
func (*GithubIssueMutation) GetClosedBy ¶
func (m *GithubIssueMutation) GetClosedBy() *GithubUser
func (*GithubIssueMutation) GetComment ¶
func (m *GithubIssueMutation) GetComment() []*GithubIssueCommentMutation
func (*GithubIssueMutation) GetCommentStatus ¶
func (m *GithubIssueMutation) GetCommentStatus() *GithubIssueSyncStatus
func (*GithubIssueMutation) GetCreated ¶
func (m *GithubIssueMutation) GetCreated() *google_protobuf.Timestamp
func (*GithubIssueMutation) GetDeletedAssignees ¶
func (m *GithubIssueMutation) GetDeletedAssignees() []int64
func (*GithubIssueMutation) GetEvent ¶
func (m *GithubIssueMutation) GetEvent() []*GithubIssueEvent
func (*GithubIssueMutation) GetEventStatus ¶
func (m *GithubIssueMutation) GetEventStatus() *GithubIssueSyncStatus
func (*GithubIssueMutation) GetId ¶
func (m *GithubIssueMutation) GetId() int64
func (*GithubIssueMutation) GetLocked ¶
func (m *GithubIssueMutation) GetLocked() *BoolChange
func (*GithubIssueMutation) GetMilestoneId ¶
func (m *GithubIssueMutation) GetMilestoneId() int64
func (*GithubIssueMutation) GetMilestoneNum ¶
func (m *GithubIssueMutation) GetMilestoneNum() int64
func (*GithubIssueMutation) GetMilestoneTitle ¶
func (m *GithubIssueMutation) GetMilestoneTitle() string
func (*GithubIssueMutation) GetNoMilestone ¶
func (m *GithubIssueMutation) GetNoMilestone() bool
func (*GithubIssueMutation) GetNotExist ¶
func (m *GithubIssueMutation) GetNotExist() bool
func (*GithubIssueMutation) GetNumber ¶
func (m *GithubIssueMutation) GetNumber() int32
func (*GithubIssueMutation) GetOwner ¶
func (m *GithubIssueMutation) GetOwner() string
func (*GithubIssueMutation) GetRemoveLabel ¶
func (m *GithubIssueMutation) GetRemoveLabel() []int64
func (*GithubIssueMutation) GetRepo ¶
func (m *GithubIssueMutation) GetRepo() string
func (*GithubIssueMutation) GetTitle ¶
func (m *GithubIssueMutation) GetTitle() string
func (*GithubIssueMutation) GetUpdated ¶
func (m *GithubIssueMutation) GetUpdated() *google_protobuf.Timestamp
func (*GithubIssueMutation) GetUser ¶
func (m *GithubIssueMutation) GetUser() *GithubUser
func (*GithubIssueMutation) ProtoMessage ¶
func (*GithubIssueMutation) ProtoMessage()
func (*GithubIssueMutation) Reset ¶
func (m *GithubIssueMutation) Reset()
func (*GithubIssueMutation) String ¶
func (m *GithubIssueMutation) String() string
type GithubIssueSyncStatus ¶
type GithubIssueSyncStatus struct {
// server_date is the "Date" response header from Github for the
// final HTTP response.
ServerDate *google_protobuf.Timestamp `protobuf:"bytes,1,opt,name=server_date,json=serverDate" json:"server_date,omitempty"`
}
GithubIssueSyncStatus notes where syncing is at for comments on an issue, This mutation type is only made at/after the same top-level mutation which created the corresponding comments.
func (*GithubIssueSyncStatus) Descriptor ¶
func (*GithubIssueSyncStatus) Descriptor() ([]byte, []int)
func (*GithubIssueSyncStatus) GetServerDate ¶
func (m *GithubIssueSyncStatus) GetServerDate() *google_protobuf.Timestamp
func (*GithubIssueSyncStatus) ProtoMessage ¶
func (*GithubIssueSyncStatus) ProtoMessage()
func (*GithubIssueSyncStatus) Reset ¶
func (m *GithubIssueSyncStatus) Reset()
func (*GithubIssueSyncStatus) String ¶
func (m *GithubIssueSyncStatus) String() string
type GithubLabel ¶
type GithubLabel struct {
Id int64 `protobuf:"varint,1,opt,name=id" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name" json:"name,omitempty"`
}
func (*GithubLabel) Descriptor ¶
func (*GithubLabel) Descriptor() ([]byte, []int)
func (*GithubLabel) GetId ¶
func (m *GithubLabel) GetId() int64
func (*GithubLabel) GetName ¶
func (m *GithubLabel) GetName() string
func (*GithubLabel) ProtoMessage ¶
func (*GithubLabel) ProtoMessage()
func (*GithubLabel) Reset ¶
func (m *GithubLabel) Reset()
func (*GithubLabel) String ¶
func (m *GithubLabel) String() string
type GithubMilestone ¶
type GithubMilestone struct {
Id int64 `protobuf:"varint,1,opt,name=id" json:"id,omitempty"`
// Following only need to be non-zero on changes:
Title string `protobuf:"bytes,2,opt,name=title" json:"title,omitempty"`
Closed *BoolChange `protobuf:"bytes,3,opt,name=closed" json:"closed,omitempty"`
Number int64 `protobuf:"varint,4,opt,name=number" json:"number,omitempty"`
}
func (*GithubMilestone) Descriptor ¶
func (*GithubMilestone) Descriptor() ([]byte, []int)
func (*GithubMilestone) GetClosed ¶
func (m *GithubMilestone) GetClosed() *BoolChange
func (*GithubMilestone) GetId ¶
func (m *GithubMilestone) GetId() int64
func (*GithubMilestone) GetNumber ¶
func (m *GithubMilestone) GetNumber() int64
func (*GithubMilestone) GetTitle ¶
func (m *GithubMilestone) GetTitle() string
func (*GithubMilestone) ProtoMessage ¶
func (*GithubMilestone) ProtoMessage()
func (*GithubMilestone) Reset ¶
func (m *GithubMilestone) Reset()
func (*GithubMilestone) String ¶
func (m *GithubMilestone) String() string
type GithubMutation ¶
type GithubMutation struct {
Owner string `protobuf:"bytes,1,opt,name=owner" json:"owner,omitempty"`
Repo string `protobuf:"bytes,2,opt,name=repo" json:"repo,omitempty"`
// Updated labels. (All must have id set at least)
Labels []*GithubLabel `protobuf:"bytes,3,rep,name=labels" json:"labels,omitempty"`
// Updated milestones. (All must have id set at least)
Milestones []*GithubMilestone `protobuf:"bytes,4,rep,name=milestones" json:"milestones,omitempty"`
}
func (*GithubMutation) Descriptor ¶
func (*GithubMutation) Descriptor() ([]byte, []int)
func (*GithubMutation) GetLabels ¶
func (m *GithubMutation) GetLabels() []*GithubLabel
func (*GithubMutation) GetMilestones ¶
func (m *GithubMutation) GetMilestones() []*GithubMilestone
func (*GithubMutation) GetOwner ¶
func (m *GithubMutation) GetOwner() string
func (*GithubMutation) GetRepo ¶
func (m *GithubMutation) GetRepo() string
func (*GithubMutation) ProtoMessage ¶
func (*GithubMutation) ProtoMessage()
func (*GithubMutation) Reset ¶
func (m *GithubMutation) Reset()
func (*GithubMutation) String ¶
func (m *GithubMutation) String() string
type GithubUser ¶
type GithubUser struct {
Id int64 `protobuf:"varint,1,opt,name=id" json:"id,omitempty"`
Login string `protobuf:"bytes,2,opt,name=login" json:"login,omitempty"`
}
func (*GithubUser) Descriptor ¶
func (*GithubUser) Descriptor() ([]byte, []int)
func (*GithubUser) GetId ¶
func (m *GithubUser) GetId() int64
func (*GithubUser) GetLogin ¶
func (m *GithubUser) GetLogin() string
func (*GithubUser) ProtoMessage ¶
func (*GithubUser) ProtoMessage()
func (*GithubUser) Reset ¶
func (m *GithubUser) Reset()
func (*GithubUser) String ¶
func (m *GithubUser) String() string
type Mutation ¶
type Mutation struct {
GithubIssue *GithubIssueMutation `protobuf:"bytes,1,opt,name=github_issue,json=githubIssue" json:"github_issue,omitempty"`
Github *GithubMutation `protobuf:"bytes,3,opt,name=github" json:"github,omitempty"`
Git *GitMutation `protobuf:"bytes,2,opt,name=git" json:"git,omitempty"`
Gerrit *GerritMutation `protobuf:"bytes,4,opt,name=gerrit" json:"gerrit,omitempty"`
}
func (*Mutation) Descriptor ¶
func (*Mutation) GetGerrit ¶
func (m *Mutation) GetGerrit() *GerritMutation
func (*Mutation) GetGit ¶
func (m *Mutation) GetGit() *GitMutation
func (*Mutation) GetGithub ¶
func (m *Mutation) GetGithub() *GithubMutation
func (*Mutation) GetGithubIssue ¶
func (m *Mutation) GetGithubIssue() *GithubIssueMutation
func (*Mutation) ProtoMessage ¶
func (*Mutation) ProtoMessage()
Click to show internal directories.
Click to hide internal directories.